@@ -19,7 +19,7 @@
 
 class Sdg_Lexer : public yyFlexLexer, public Sdg_Base{
  public:
-	Sdg_Lexer(std::istream &file){switch_streams(&file,&std::cout); yy_flex_debug = 1; }
+	Sdg_Lexer(std::istream &file):Sdg_Base("Sdg_Lexer"){switch_streams(&file,&std::cout); yy_flex_debug = 1; }
 	virtual ~Sdg_Lexer(){ }
 	virtual int yylex(FLEXFIX);
  protected:
